@@ -2,7 +2,7 @@ package Plack::Middleware::Profiler::NYTProf;
 use strict;
 use warnings;
 use parent qw(Plack::Middleware);
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Plack::Util::Accessor qw(
     enable_profile
@@ -37,6 +37,13 @@ sub prepare_app {
     $self->_setup_enable_reporting;
     $self->_setup_report_dir;
     $self->_setup_nytprofhtml_path;
+
+    $ENV{NYTPROF} = $self->env_nytprof || 'start=no:sigexit=int';
+
+    # NYTPROF environment variable is set in Devel::NYTProf::Core
+    # so, we load Devel::NYTProf here.
+    require Devel::NYTProf;
+    DB::disable_profile();
 }
 
 sub _setup_profiling_file_paths {
@@ -159,16 +166,6 @@ sub _setup_profiler {
     my $pid = $$;
     return if $PROFILER_SETUPED{$pid};
     $PROFILER_SETUPED{$pid} = 1;
-
-    my $is_profiler_enabled = $self->enable_profile->($env);
-    return unless $is_profiler_enabled;
-
-    $ENV{NYTPROF} = $self->env_nytprof || 'start=no';
-
-    # NYTPROF environment variable is set in Devel::NYTProf::Core
-    # so, we load Devel::NYTProf here.
-    require Devel::NYTProf;
-    DB::disable_profile();
 }
 
 sub start_profiling {
